@@ -81,7 +81,7 @@ find_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 		find_dialog = create_find_dialog();
 
 	if(!GTK_WIDGET_VISIBLE(find_dialog->window)) {
-		gtk_window_position (GTK_WINDOW(find_dialog->window), GTK_WIN_POS_MOUSE);
+		gtk_window_set_position (GTK_WINDOW(find_dialog->window), GTK_WIN_POS_MOUSE);
 		gtk_window_set_default(GTK_WINDOW(find_dialog->window), find_dialog->f_next);
 		gtk_widget_show(find_dialog->window);
 	}
@@ -96,7 +96,7 @@ advanced_find_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbn
 		win->advanced_find_dialog = create_advanced_find_dialog(win);
 
 	if(!GTK_WIDGET_VISIBLE(win->advanced_find_dialog->window)) {
-		gtk_window_position (GTK_WINDOW(win->advanced_find_dialog->window), GTK_WIN_POS_MOUSE);
+		gtk_window_set_position (GTK_WINDOW(win->advanced_find_dialog->window), GTK_WIN_POS_MOUSE);
 		gtk_window_set_default(GTK_WINDOW(win->advanced_find_dialog->window),
 							   win->advanced_find_dialog->f_close);
 		gtk_widget_show(win->advanced_find_dialog->window);
@@ -112,7 +112,7 @@ replace_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 		replace_dialog = create_replace_dialog();
 
 	if(!GTK_WIDGET_VISIBLE(replace_dialog->window)) {
-		gtk_window_position (GTK_WINDOW(replace_dialog->window), GTK_WIN_POS_MOUSE);
+		gtk_window_set_position (GTK_WINDOW(replace_dialog->window), GTK_WIN_POS_MOUSE);
 		gtk_window_set_default(GTK_WINDOW(replace_dialog->window), replace_dialog->next);
 		gtk_widget_show(replace_dialog->window);
 	}
@@ -126,7 +126,7 @@ jump_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 		jump_dialog = create_jump_dialog();
 
 	if(!GTK_WIDGET_VISIBLE(jump_dialog->window)) {
-		gtk_window_position (GTK_WINDOW(jump_dialog->window), GTK_WIN_POS_MOUSE);
+		gtk_window_set_position (GTK_WINDOW(jump_dialog->window), GTK_WIN_POS_MOUSE);
 		gtk_window_set_default(GTK_WINDOW(jump_dialog->window), jump_dialog->ok);
 		gtk_widget_show(jump_dialog->window);
 	}
